@@ -4,12 +4,12 @@ import typing
 
 import sqlalchemy as sa
 
-from lime_uow.resources.resource import Resource
+from lime_uow import resource
 
 __all__ = ("SqlAlchemyTransaction",)
 
 
-class SqlAlchemyTransaction(Resource[sa.engine.Transaction]):
+class SqlAlchemyTransaction(resource.Resource[sa.engine.Transaction]):
     def __init__(self, /, engine: sa.engine.Engine):
         self._engine = engine
         self._transaction: typing.Optional[sa.engine.Transaction] = None
