@@ -3,16 +3,13 @@ from __future__ import annotations
 import abc
 import typing
 
-from lime_uow import exceptions, resources, shared_resource_manager
+from lime_uow import exceptions, resource, shared_resource_manager
 
 __all__ = (
     "PlaceholderUnitOfWork",
     "UnitOfWork",
 )
 
-
-from lime_uow.resources import resource
-
 # noinspection PyTypeChecker
 T = typing.TypeVar("T", bound="UnitOfWork")
 
@@ -20,26 +17,26 @@ T = typing.TypeVar("T", bound="UnitOfWork")
 class UnitOfWork(abc.ABC):
     def __init__(self):
         self.__resources: typing.Optional[
-            typing.Dict[str, resources.Resource[typing.Any]]
+            typing.Dict[str, resource.Resource[typing.Any]]
         ] = None
         self.__resources_validated = False
         self.__shared_resource_manager: typing.Optional[
-            shared_resource_manager.SharedResources
+            shared_resource_manager.SharedResourceManager
         ] = None
 
     def __enter__(self: T) -> T:
         if self.__shared_resource_manager is None:
             shared_resources = self.create_shared_resources()
-            self.__shared_resource_manager = shared_resource_manager.SharedResources(*shared_resources)
+            self.__shared_resource_manager = (
+                shared_resource_manager.SharedResourceManager(*shared_resources)
+            )
         fresh_resources = self.create_resources(self.__shared_resource_manager)
-        resources.check_for_ambiguous_implementations(fresh_resources)
-        self.__resources = {
-            resource.interface().__name__: resource for resource in fresh_resources
-        }
+        resource.check_for_ambiguous_implementations(fresh_resources)
+        self.__resources = {r.interface().__name__: r for r in fresh_resources}
         self.__resources_validated = True
         return self
 
-    def __exit__(self, *args):
+    def __exit__(self, *args) -> typing.Literal[False]:
         errors: typing.List[exceptions.RollbackError] = []
         try:
             self.rollback()
@@ -48,6 +45,7 @@ class UnitOfWork(abc.ABC):
         self.__resources = None
         if errors:
             raise exceptions.RollbackErrors(*errors)
+        return False
 
     def close(self) -> None:
         if self.__shared_resource_manager:
@@ -61,7 +59,7 @@ class UnitOfWork(abc.ABC):
         else:
             return resource_type.__name__ in self.__resources.keys()
 
-    def get(self, resource_type: typing.Type[resources.Resource[T]]) -> T:
+    def get(self, /, resource_type: typing.Type[resource.Resource[T]]) -> T:
         if self.__resources is None:
             raise exceptions.OutsideTransactionError()
         else:
@@ -79,12 +77,14 @@ class UnitOfWork(abc.ABC):
 
     @abc.abstractmethod
     def create_resources(
-        self, /, shared_resources: shared_resource_manager.SharedResources
-    ) -> typing.Iterable[resources.Resource[typing.Any]]:
+        self, /, shared_resources: shared_resource_manager.SharedResourceManager
+    ) -> typing.Iterable[resource.Resource[typing.Any]]:
         raise NotImplementedError
 
     @abc.abstractmethod
-    def create_shared_resources(self) -> typing.Iterable[resources.Resource[typing.Any]]:
+    def create_shared_resources(
+        self,
+    ) -> typing.Iterable[resource.Resource[typing.Any]]:
         raise NotImplementedError
 
     def rollback(self):
@@ -92,9 +92,9 @@ class UnitOfWork(abc.ABC):
         if self.__resources is None:
             raise exceptions.OutsideTransactionError()
         else:
-            for resource in self.__resources.values():
+            for r in self.__resources.values():
                 try:
-                    resource.rollback()
+                    r.rollback()
                 except Exception as e:
                     errors.append(
                         exceptions.RollbackError(
@@ -111,8 +111,8 @@ class UnitOfWork(abc.ABC):
             if self.__resources is None:
                 raise exceptions.OutsideTransactionError()
             else:
-                for resource in self.__resources.values():
-                    resource.save()
+                for r in self.__resources.values():
+                    r.save()
         except:
             self.rollback()
             raise
@@ -123,9 +123,9 @@ class PlaceholderUnitOfWork(UnitOfWork):
         super().__init__()
 
     def create_resources(
-        self, shared_resources: shared_resource_manager.SharedResources
-    ) -> typing.List[resources.Resource[typing.Any]]:
+        self, shared_resources: shared_resource_manager.SharedResourceManager
+    ) -> typing.List[resource.Resource[typing.Any]]:
         return []
 
-    def create_shared_resources(self) -> typing.List[resources.Resource[typing.Any]]:
+    def create_shared_resources(self) -> typing.List[resource.Resource[typing.Any]]:
         return []
